==> opennms_21.0.3-1.tar.gz: opennms-source/features/collection/client-rpc/src/test/java/org/opennms/netmgt/collection/client/rpc/CollectorRequestDTOTest.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.client.rpc;

import java.util.Arrays;
import java.util.Collection;

import org.junit.runners.Parameterized.Parameters;
import org.opennms.core.test.xml.XmlTestNoCastor;
import org.opennms.netmgt.collection.api.ServiceCollector;
import org.opennms.netmgt.collection.dto.CollectionAgentDTO;

public class CollectorRequestDTOTest extends XmlTestNoCastor<CollectorRequestDTO> {

    public CollectorRequestDTOTest(CollectorRequestDTO sampleObject, Object sampleXml) {
        super(sampleObject, sampleXml, null);
    }

    @Parameters
    public static Collection<Object[]> data() throws Exception {
        CollectionAgentDTO agent = new CollectionAgentDTO();
        CollectorRequestDTO request = new CollectorRequestDTO();
        request.setAgent(agent);
        request.setLocation("HQ");
        request.setClassName(ServiceCollector.class.getCanonicalName());
        request.addAttribute("key", "value");

        return Arrays.asList(new Object[][] {
            {
                request,
                "<collector-request location=\"HQ\" class-name=\"org.opennms.netmgt.collection.api.ServiceCollector\">\n" + 
                "   <agent type=\"0\" node-id=\"0\" sys-up-time=\"0\"/>\n" + 
                "   <attribute key=\"key\"><![CDATA[value]]></attribute>\n" + 
                "</collector-request>"
            }
        });
    }
}

==> opennms_22.0.3-1.tar.gz: opennms-source/features/collection/client-rpc/src/test/java/org/opennms/netmgt/collection/client/rpc/CollectorRequestDTOTest.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.client.rpc;

import java.util.Arrays;
import java.util.Collection;

import org.junit.runners.Parameterized.Parameters;
import org.opennms.core.test.xml.XmlTestNoCastor;
import org.opennms.netmgt.collection.api.ServiceCollector;
import org.opennms.netmgt.collection.dto.CollectionAgentDTO;

public class CollectorRequestDTOTest extends XmlTestNoCastor<CollectorRequestDTO> {

    public CollectorRequestDTOTest(CollectorRequestDTO sampleObject, Object sampleXml) {
        super(sampleObject, sampleXml, null);
    }

    @Parameters
    public static Collection<Object[]> data() throws Exception {
        CollectionAgentDTO agent = new CollectionAgentDTO();
        CollectorRequestDTO request = new CollectorRequestDTO();
        request.setAgent(agent);
        request.setLocation("HQ");
        request.setClassName(ServiceCollector.class.getCanonicalName());
        request.addAttribute("key", "value");

        return Arrays.asList(new Object[][] {
            {
                request,
                "<collector-request location=\"HQ\" class-name=\"org.opennms.netmgt.collection.api.ServiceCollector\">\n" + 
                "   <agent node-id=\"0\" sys-up-time=\"0\"/>\n" + 
                "   <attribute key=\"key\"><![CDATA[value]]></attribute>\n" + 
                "</collector-request>"
            }
        });
    }
}
